NELMON: Monitoring tools for Nagios and compatible products
===========================================================

Install using pip:

.. code-block:: bash

    $ pip install nelmon

Or if you want the plugins to be installed to your Nagios plugins directory

.. code-block:: bash

    $ pip install nelmon --install-option="--install-scripts=/usr/local/nagios/libexec"

When you need to upgrade:

.. code-block:: bash

    $ pip install -U nelmon --install-option="--install-scripts=/usr/local/nagios/libexec"
